<?php
/**
 *
 * Ventcamp WP Theme functions
 *
 * @author Vivaco
 * @license Commercial License
 * @link http://vivaco.com
 * @copyright 2016 Vivaco
 * @package Ventcamp
 * @version 1.0.0
 *
 */
defined('ABSPATH') or die('No direct access');

/*
*   By default LESS files are compiled only after you hit "Save in WP -> Customize"
*   This setting will override this option and compile LESS on each webpage load *   refresh. Help to debug a lot
*/
define('VENTCAMP_LESS_COMPILE_DEBUG', false);

// Theme main variables
define('VENTCAMP_BLOG_IMAGE_LARGE_W', 860);
define('VENTCAMP_BLOG_IMAGE_LARGE_H', 340);

define('VENTCAMP_FOOTER_RECENTCOMMENTS_LENGTH', 25); // Recent comments title length in footer
define('VENTCAMP_FOOTER_RECENTPOSTS_LENGTH', 25);	// Recent posts title length in footer

if( !function_exists('ventcamp_theme_setup') ) {
	function ventcamp_theme_setup() {
		load_theme_textdomain( 'ventcamp', get_template_directory() . '/languages' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'caption' );

		if ( ! isset( $content_width ) ) $content_width = 960;

		add_editor_style();
		
		add_theme_support( 'custom-header' );
		add_theme_support( 'custom-background' );
		
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'automatic-feed-links' ).

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'quote',
			'link',
		) );

		add_image_size( '70x70', 70, 70, false );

		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'ventcamp' ),
			'footer'  => esc_html__( 'Footer Menu', 'ventcamp' ),
		) );
	}
}
add_action( 'after_setup_theme', 'ventcamp_theme_setup' );

/* Enqueue Ventcamp styles */
if( !function_exists('ventcamp_enqueue_styles') ) {
	function ventcamp_enqueue_styles() {
	
		wp_enqueue_style('bootstrap', get_template_directory_uri() . '/css/lib/bootstrap.min.css');
		wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/lib/font-awesome.min.css');
		wp_enqueue_style('font-lineicons', get_template_directory_uri() . '/css/lib/font-lineicons.css');
		wp_enqueue_style('toastr', get_template_directory_uri() . '/css/lib/toastr.min.css');
		wp_enqueue_style('ventcamp-style', get_stylesheet_directory_uri() . '/style.css');
		
		//wp_enqueue_style( 'ventcamp-less-styles', get_template_directory_uri() . '/css/less/style.less');

	}
	add_action('wp_enqueue_scripts', 'ventcamp_enqueue_styles', 50);
}

/* Load theme Main scripts */
if( !function_exists('ventcamp_enqueue_scripts') ) {
	function ventcamp_enqueue_scripts() {

		// Load the Internet Explorer specific scripts
		wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/lib/html5shiv.js' );
		wp_enqueue_script( 'respond', get_template_directory_uri() . '/js/lib/respond.min.js' );
		wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );
		wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );

		//Load main JS lib scripts
		wp_enqueue_script( 'plugin-helpers', get_template_directory_uri() . "/js/lib/jquery.plugin.min.js", array('jquery'), false, true );
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . "/js/lib/bootstrap.min.js", array('jquery'), false, true );
		wp_enqueue_script( 'jquery-waypoints', get_template_directory_uri() . "/js/lib/jquery.waypoints.min.js", array('jquery'), false, true );
		wp_enqueue_script( 'jquery-countdown', get_template_directory_uri() . "/js/lib/jquery.countdown.min.js", array('jquery', 'ventcamp-plugin'), false, true );
		
		//Load Main Theme Js script
		wp_enqueue_script( 'ventcamp-main', get_template_directory_uri() . "/js/ventcamp.js", array('jquery'), false, true );
		
		//Load comment scripts if page has comments enabled
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

	}
}
add_action( 'wp_enqueue_scripts', 'ventcamp_enqueue_scripts' );

/* Load theme Admin scripts */
if( !function_exists('ventcamp_enqueue_admin_scripts') ) {
	function ventcamp_enqueue_admin_scripts() {
		
		//Load Default VC scripts in admin for additonal functional
		wp_enqueue_script('media-upload');
		wp_enqueue_script('thickbox');
		wp_enqueue_style('thickbox');

		//Load Theme admin scripts
		wp_enqueue_script( 'ventcamp-admin', get_template_directory_uri() . '/js/ventcamp-admin.js', array('jquery'));
		wp_enqueue_style( 'ventcamp-admin-style', get_template_directory_uri() . '/cache/admin-style.css');
		wp_enqueue_style( 'venttcamp-admin-woocommerce', get_template_directory_uri() . '/css/ventcamp-admin-woocommerce.css');
	}
}
add_action('admin_enqueue_scripts', 'ventcamp_enqueue_admin_scripts');

// Include Theme libraries and dependencies
if (function_exists('is_plugin_active')){

	//Ventcamp Core
	if (is_plugin_active('ventcamp-core/ventcamp-core.php')) {
		require get_template_directory() . '/includes/ventcamp_customizer.php';
	}

	//WooCommerce
	if (is_plugin_active('woocommerce/woocommerce.php')) {
		require get_template_directory() . '/includes/ventcamp_woocommerce.php';
	}
 
}
require get_template_directory() . '/includes/ventcamp_widgets.php'; // Add ventcamp widgets
require get_template_directory() . '/includes/ventcamp_event.php'; // Add Event schedule
require get_template_directory() . '/includes/ventcamp_template_tags.php'; // Add misc template overrides
require get_template_directory() . '/includes/lib/aqua-resizer/aqua-resizer.php'; //Add aqua thumbnail resizer

//Adding theme specific widget overrides
require get_template_directory() . '/includes/widgets/ventcamp_widget_Recent_Posts.php';
require get_template_directory() . '/includes/widgets/ventcamp_widget_Recent_Comments.php';
require get_template_directory() . '/includes/widgets/ventcamp_widget_About.php';

//check if needed CSS files exist, create them if not
if( !function_exists('ventcamp_check_css_cache') ) {
	function ventcamp_check_css_cache(){
		if( !file_exists( get_template_directory() . '/cache/theme-style.css' ) || !file_exists( get_template_directory() . '/cache/admin-style.css' ) || !file_exists( get_template_directory() . '/cache/ventcamp-fonts.css' ) ) {
			ventcamp_less_compile(); //re-create new LESS files
		}
	}
}
add_action( 'wp_enqueue_scripts', 'ventcamp_check_css_cache', 100, 0);

//Include Custom JS in footer
if( !function_exists('ventcamp_append_footer_scripts') ) {
	function ventcamp_append_footer_scripts(){
		$customcode_global_js = ventcamp_option('customcode_global_js');

		if(!empty($customcode_global_js)){
			echo "<script type='text/javascript'>\n;(function($) {\n" . esc_js($customcode_global_js) . "\n})(jQuery);\n</script>";
		}
	}
}
add_action( 'wp_footer', 'ventcamp_append_footer_scripts', 100, 0);

//Include Custom CSS to header
if( !function_exists('ventcamp_append_head_styles') ) {
	function ventcamp_append_head_styles(){
		$customcode_global_css = ventcamp_option('customcode_global_css');
		if(!empty($customcode_global_css)){
			echo "<style type='text/css'>\n" . esc_html( $customcode_global_css, array( "\'", '\"' ) ) . "\n</style>";
		}

		$customcode_tablet_css = ventcamp_option('customcode_tablet_css');
		if(!empty($customcode_tablet_css)){
			echo "<style type='text/css'>\n@media (max-width: 992px) {\n" . esc_html( $customcode_tablet_css, array( "\'", '\"' ) ) . "\n}\n</style>";
		}

		$customcode_phone_css = ventcamp_option('customcode_phone_css');
		if(!empty($customcode_phone_css)){
			echo "<style type='text/css'>\n@media (max-width: 767px) {\n" . esc_html(  $customcode_phone_css, array( "\'", '\"' ) ) . "\n}\n</style>";
		}

	}
}
add_action( 'wp_head', 'ventcamp_append_head_styles', 100, 0);

//Change default page template to Fullwidth
if( !function_exists('ventcamp_change_default_template') ) {
	function ventcamp_change_default_template() {
	  return esc_html__( 'Full width', 'ventcamp' );
	}
}
add_filter( 'default_page_template_title', 'ventcamp_change_default_template', 10, 2 );

// Add custom button to Read more
function ventcamp_excerpt_more($more) {
	return '<a class="btn btn-alt btn-sm read-more" href="'. get_permalink() . '"> READ MORE</a>';
}
add_filter('the_content_more_link', 'ventcamp_excerpt_more');

//Ventcamp default menu
function ventcamp_default_menu() {
	$html = '<ul class="navigation-list pull-left">';
		$html .= '<li class="menu-item menu-item-type-custom menu-item-object-custom current-menu-item current_page_item menu-item-home">';
			$html .= '<a href="' . esc_url( home_url() ) . '/wp-admin/nav-menus.php" title="' . esc_html__( 'Home', 'ventcamp' ) . '">';
				$html .= esc_html__( 'ADD THEME MENU', 'ventcamp' );
			$html .= '</a>';
		$html .= '</li>';
	$html .= '</ul>';
	echo $html;
} // end ventcamp_default_men

/* Custom comments function */
if(!function_exists('ventcamp_comment')) {
	function ventcamp_comment($comment, $args, $depth) { ?>
		<li class="comment" <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">

			<div class="comment-body">

				<div class="comment-author vcard">
					<?php echo get_avatar($comment,$args['avatar_size']); ?>
					<cite class="fn base_clr_txt"><?php echo get_comment_author_link() ?></cite> <span class="says base_clr_txt"></span>
				</div>

				<div class="comment-meta commentmetadata">
					<?php printf(__('%1$s @ %2$s', 'ventcamp'), get_comment_date(),  get_comment_time()) ?></a><?php edit_comment_link(__('Edit', 'ventcamp'),'  ','') ?>
				</div>

				<div class="comment-data">
					<?php if ($comment->comment_approved == '0') : ?>
					<em><?php echo esc_html__('<em>Your comment is awaiting moderation.</em>', 'ventcamp') ?></em>
					<br />
					<?php endif; ?>
					<?php comment_text() ?>
				</div>

				<?php if ( have_comments() ) : ?>
						<?php comment_reply_link(array_merge( $args, array('before' => '<div class="reply"><span class="reply-icon base_clr_txt"><i class="fa fa-comment-o"></i></span>' ,'depth' => $depth, 'max_depth' => $args['max_depth'], 'after' => '</div>'))) ?>
				<?php endif; // end have_comments() ?>

			</div>

	<?php }
}

//Add the TGM_Plugin_Activation class.
require get_template_directory() . '/includes/lib/tgm-plugin-activation/class-tgm-plugin-activation.php';
if( !function_exists('ventcamp_theme_register_required_plugins') ) {
	function ventcamp_theme_register_required_plugins() {
		/**
		 * Array of plugin arrays. Required keys are name and slug.
		 * If the source is NOT from the .org repo, then source is also required.
		 */
		$plugins = array(
			array(
				'name'               => 'Ventcamp Core',
				'slug'               => 'ventcamp-core',
				'source'             => 'http://vivaco.com/ext/ventcamp-core-1.0.zip',
				'required'           => true,
				'version'            => '1.0',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),			
			
			array(
				'name'               => 'Ventcamp Visual Composer Shortcodes',
				'slug'               => 'ventcamp-vc-shortcodes',
				'source'             => 'http://vivaco.com/ext/ventcamp-vc-shortcodes-1.0.zip',
				'required'           => true,
				'version'            => '1.0',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			
			array(
				'name'               => 'Visual Composer', // The plugin name.
				'slug'               => 'js_composer', // The plugin slug (typically the folder name).
				'source'             => 'http://vivaco.com/ext/js_composer_4.10.zip', // The plugin source.
				'required'           => true, // If false, the plugin is only 'recommended' instead of required.
				'version'            => '4.10', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
				'external_url'       => '', // If set, overrides default API URL and points to an external URL.
			),
			array(
				'name'               => 'Envato WordPress Toolkit',
				'slug'               => 'envato-wordpress-toolkit-master',
				'source'             => 'http://github.com/envato/envato-wordpress-toolkit/archive/master.zip',
				'required'           => false,
				'version'            => '1.7.2',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => 'Contact Form 7',
				'slug'               => 'contact-form-7',
				'source'             => 'http://downloads.wordpress.org/plugin/contact-form-7.4.4.zip',
				'required'           => false,
				'version'            => '4.4',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => 'Contact Form DB',
				'slug'               => 'contact-form-7-to-database-extension',
				'source'             => 'http://downloads.wordpress.org/plugin/contact-form-7-to-database-extension.2.9.16.zip',
				'required'           => false,
				'version'            => '2.9.16',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => 'WooCommerce',
				'slug'               => 'woocommerce',
				'source'             => 'https://downloads.wordpress.org/plugin/woocommerce.zip',
				'required'           => false,
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => 'WooCommerce Events',
				'slug'               => 'woocommerce-events',
				'source'             => 'http://vivaco.com/ext/woocommerce-events-1.1.11.zip',
				'required'           => false,
				'version'            => '1.1.11',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
		);

		/**
		 * Array of configuration settings. Amend each line as needed.
		 * If you want the default strings to be available under your own theme domain,
		 * leave the strings uncommented.
		 * Some of the strings are added into a sprintf, so see the comments at the
		 * end of each line for what each argument will be.
		 */
		$config = array(
			'default_path' => '',                      // Default absolute path to pre-packaged plugins.
			'menu'         => 'tgmpa-install-plugins', // Menu slug.
			'has_notices'  => true,                    // Show admin notices or not.
			'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
			'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
			'is_automatic' => true,                   // Automatically activate plugins after installation or not.
			'message'      => '',                      // Message to output right before the plugins table.
			'strings'      => array(
				'page_title'                      =>  esc_html__( 'Install Required Plugins', 'ventcamp' ),
				'menu_title'                      => esc_html__( 'Install Plugins', 'ventcamp' ),
				'installing'                      => esc_html__( 'Installing Plugin: %s', 'ventcamp' ), // %s = plugin name.
				'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'ventcamp' ),
				'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'ventcamp' ), // %1$s = plugin name(s).
				'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'ventcamp' ), // %1$s = plugin name(s).
				'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'ventcamp' ), // %1$s = plugin name(s).
				'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'ventcamp' ), // %1$s = plugin name(s).
				'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'ventcamp' ), // %1$s = plugin name(s).
				'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'ventcamp' ), // %1$s = plugin name(s).
				'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'ventcamp' ), // %1$s = plugin name(s).
				'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'ventcamp' ), // %1$s = plugin name(s).
				'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'ventcamp' ),
				'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'ventcamp' ),
				'return'                          => esc_html__( 'Return to Required Plugins Installer', 'ventcamp' ),
				'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'ventcamp' ),
				'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s', 'ventcamp' ), // %s = dashboard link.
				'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
			)
		);

		tgmpa( $plugins, $config );
	}
}
add_action( 'tgmpa_register', 'ventcamp_theme_register_required_plugins' );

//Check if theme has enough permisssions to write /cache files
function write_permissions_error() {
	?>
	<div class="notice error write_permissions_error is-dismissible" >
		<p><?php esc_html__( 'Error, files cache/theme-style.css, cache/admin-style.css or cache/ventcamp-fonts.css could not be written! Please make sure there are enough permissions for a theme to create these files in /cache directory ', 'ventcamp' ); ?><a href="#">How to fix it & details</a></p>
	</div>


	<?php
}

//Check if LESS Debug is on, to instantly regenerate styles from LESS on each page reload
if (VENTCAMP_LESS_COMPILE_DEBUG == true){
	add_action( 'after_setup_theme', 'ventcamp_less_compile' );
} else {
	add_action( 'customize_save_after', 'ventcamp_less_compile', 99 );
}

//Add API config page
if( !function_exists('register_ventcamp_api_page') ) {
	function register_ventcamp_api_page(){
		add_theme_page( esc_html__('API Integrations', 'ventcamp'), esc_html__( 'API Integrations', 'ventcamp' ), 'manage_options', 'edit_theme_options', 'ventcamp_api_integrations' );
	}
}
add_action( 'admin_menu', 'register_ventcamp_api_page' );

//Add API Integrations page
if( !function_exists('ventcamp_api_integrations') ) {
	function ventcamp_api_integrations(){
		if('POST' === $_SERVER['REQUEST_METHOD']){
			if ( !wp_verify_nonce($_POST['_wpnonce'])) {
				wp_die( 'Nonce is invalid', 'Error');
			} else {
				update_option( 'ventcamp_mailchimp_api_key', $_POST['ventcamp_mailchimp_api_key'] );
				?>
			<div class="updated"><p><strong><?php esc_html_e('Options saved.', 'ventcamp' ); ?></strong></p></div>
	<?php   }
		}

		$ventcamp_mailchimp_api_key = get_option('ventcamp_mailchimp_api_key');

	 ?>
	<div class='wrap'>
		<h2><?php esc_html_e( 'Ventcamp API Integrations', 'ventcamp' ); ?></h2>

		<form method="post" action="<?php echo str_replace('%7E', '~', esc_url($_SERVER['REQUEST_URI']));?>">
		<?php wp_nonce_field(); ?>

		<p><?php esc_html_e( 'Mailchimp API key', 'ventcamp' ) ?>
		<input type="text" name='ventcamp_mailchimp_api_key' value='<?php echo $ventcamp_mailchimp_api_key;?>' size='45'>
		</p>

		<input type="submit" class='button' value="<?php esc_html_e( 'Save options', 'ventcamp' ); ?>">
		</form>

	</div>
		<?php
	}
}

// Ventcamp title shortening function
if (!function_exists('ventcamp_short_title')) {
	function ventcamp_short_title($text, $chars_limit = 30) {

		// Change to the number of characters you want to display
		$chars_text = strlen($text);
		$text = $text." ";
		$text = substr($text,0,$chars_limit);
		$text = substr($text,0,strrpos($text,' '));

		if ($chars_text > $chars_limit){
			$text = $text."...";
		}

	return $text;

	}
}

// Ventcamp options
if( !function_exists('ventcamp_option') ) {
	function ventcamp_option($option = ''){
		if ( class_exists( 'Kirki' ) ){
			return Kirki::get_option( 'ventcamp_theme_config' , $option );
		} else {
			return '';
		}
	}
}

//Fallback functions if core plugin is disabled
if ( !class_exists( 'Kirki' ) ){
	function ventcamp_pagination() {
		echo paginate_links(array(
			'prev_text'          => esc_html__('&larr;', 'ventcamp'),
			'next_text'          => esc_html__('&rarr;', 'ventcamp'),
		));
	}
};


?>